@@ -74,8 +74,6 @@
 typedef struct {
 	EmpathyChat *current_chat;
 	GList       *chats;
-	GList       *chats_new_msg;
-	GList       *chats_composing;
 	gboolean     page_added;
 	gboolean     dnd_same_window;
 	EmpathyChatroomManager *chatroom_manager;
@@ -445,11 +443,8 @@ get_all_unread_messages (EmpathyChatWindowPriv *priv)
 	GList *l;
 	guint nb = 0;
 
-	for (l = priv->chats_new_msg; l != NULL; l = g_list_next (l)) {
-		EmpathyChat *chat = l->data;
-
-		nb += empathy_chat_get_nb_unread_messages (chat);
-	}
+	for (l = priv->chats; l != NULL; l = g_list_next (l))
+		nb += empathy_chat_get_nb_unread_messages (EMPATHY_CHAT (l->data));
 
 	return nb;
 }
@@ -531,7 +526,7 @@ chat_window_title_update (EmpathyChatWindowPriv *priv)
 }
 
 static void
-chat_window_icon_update (EmpathyChatWindowPriv *priv)
+chat_window_icon_update (EmpathyChatWindowPriv *priv, gboolean new_messages)
 {
 	GdkPixbuf      *icon;
 	EmpathyContact *remote_contact;
@@ -541,7 +536,7 @@ chat_window_icon_update (EmpathyChatWindowPriv *priv)
 	n_chats = g_list_length (priv->chats);
 
 	/* Update window icon */
-	if (priv->chats_new_msg) {
+	if (new_messages) {
 		gtk_window_set_icon_name (GTK_WINDOW (priv->dialog),
 					  EMPATHY_IMAGE_MESSAGE);
 	} else {
@@ -604,7 +599,7 @@ chat_window_update (EmpathyChatWindow *window)
 
 	chat_window_title_update (priv);
 
-	chat_window_icon_update (priv);
+	chat_window_icon_update (priv, get_all_unread_messages (priv) > 0);
 
 	chat_window_close_button_update (priv,
 					 num_pages);
@@ -665,10 +660,10 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 		/* No TpChat, we are disconnected */
 		icon_name = NULL;
 	}
-	else if (g_list_find (priv->chats_new_msg, chat)) {
+	else if (empathy_chat_get_nb_unread_messages (chat) > 0) {
 		icon_name = EMPATHY_IMAGE_MESSAGE;
 	}
-	else if (g_list_find (priv->chats_composing, chat)) {
+	else if (empathy_chat_is_composing (chat)) {
 		icon_name = EMPATHY_IMAGE_TYPING;
 	}
 	else if (remote_contact) {
@@ -713,7 +708,7 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 				      _("Topic:"), subject);
 	}
 
-	if (g_list_find (priv->chats_composing, chat)) {
+	if (empathy_chat_is_composing (chat)) {
 		append_markup_printf (tooltip, "\n%s", _("Typing a message."));
 	}
 
@@ -1242,16 +1237,6 @@ chat_window_composing_cb (EmpathyChat       *chat,
 			  gboolean          is_composing,
 			  EmpathyChatWindow *window)
 {
-	EmpathyChatWindowPriv *priv;
-
-	priv = GET_PRIV (window);
-
-	if (is_composing && !g_list_find (priv->chats_composing, chat)) {
-		priv->chats_composing = g_list_prepend (priv->chats_composing, chat);
-	} else {
-		priv->chats_composing = g_list_remove (priv->chats_composing, chat);
-	}
-
 	chat_window_update_chat_tab (chat);
 }
 
@@ -1354,7 +1339,7 @@ chat_window_show_or_update_notification (EmpathyChatWindow *window,
 }
 
 static void
-chat_window_set_highlight_room_tab_label (EmpathyChat *chat)
+chat_window_set_highlight_room_labels (EmpathyChat *chat)
 {
 	gchar *markup;
 	GtkWidget *widget;
@@ -1368,6 +1353,10 @@ chat_window_set_highlight_room_tab_label (EmpathyChat *chat)
 
 	widget = g_object_get_data (G_OBJECT (chat), "chat-window-tab-label");
 	gtk_label_set_markup (GTK_LABEL (widget), markup);
+
+	widget = g_object_get_data (G_OBJECT (chat), "chat-window-menu-label");
+	gtk_label_set_markup (GTK_LABEL (widget), markup);
+
 	g_free (markup);
 }
 
@@ -1423,8 +1412,8 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 		return;
 	}
 
-	if (!g_list_find (priv->chats_new_msg, chat)) {
-		priv->chats_new_msg = g_list_prepend (priv->chats_new_msg, chat);
+	/* Update the chat tab if this is the first unread message */
+	if (empathy_chat_get_nb_unread_messages (chat) == 1) {
 		chat_window_update_chat_tab (chat);
 	}
 
@@ -1459,7 +1448,7 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 	if (needs_urgency) {
 		if (!has_focus) {
 			chat_window_set_urgency_hint (window, TRUE);
-			chat_window_set_highlight_room_tab_label (chat);
+			chat_window_set_highlight_room_labels (chat);
 		}
 
 		empathy_sound_manager_play (priv->sound_mgr, GTK_WIDGET (priv->dialog),
@@ -1473,7 +1462,7 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 
 	/* update the number of unread messages and the window icon */
 	chat_window_title_update (priv);
-	chat_window_icon_update (priv);
+	chat_window_icon_update (priv, TRUE);
 }
 
 static GtkNotebook *
@@ -1532,7 +1521,6 @@ chat_window_page_switched_cb (GtkNotebook      *notebook,
 	}
 
 	priv->current_chat = chat;
-	priv->chats_new_msg = g_list_remove (priv->chats_new_msg, chat);
 	empathy_chat_messages_read (chat);
 
 	chat_window_update_chat_tab (chat);
@@ -1624,9 +1612,7 @@ chat_window_page_removed_cb (GtkNotebook      *notebook,
 
 	/* Keep list of chats up to date */
 	priv->chats = g_list_remove (priv->chats, chat);
-	priv->chats_new_msg = g_list_remove (priv->chats_new_msg, chat);
 	empathy_chat_messages_read (chat);
-	priv->chats_composing = g_list_remove (priv->chats_composing, chat);
 
 	if (priv->chats == NULL) {
 		g_object_unref (window);
@@ -1644,7 +1630,6 @@ chat_window_focus_in_event_cb (GtkWidget        *widget,
 
 	priv = GET_PRIV (window);
 
-	priv->chats_new_msg = g_list_remove (priv->chats_new_msg, priv->current_chat);
 	empathy_chat_messages_read (priv->current_chat);
 
 	chat_window_set_urgency_hint (window, FALSE);
@@ -2099,8 +2084,6 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 
 	/* Set up private details */
 	priv->chats = NULL;
-	priv->chats_new_msg = NULL;
-	priv->chats_composing = NULL;
 	priv->current_chat = NULL;
 	priv->notification = NULL;
 
